@@ -34,6 +34,9 @@ public:
 	virtual bool has_destin_layer()  = 0;
 	virtual pe REF source_pe(int c)  = 0;
 	virtual pe REF destin_pe(int c)  = 0;
+	virtual DATA get_connection_weight(int connection) = 0;
+	virtual bool set_connection_weight(int connection, DATA value) = 0;
+	virtual bool set_misc(DATA * data, int dimension) = 0;
 	virtual	bool setup (layer PTR source_layer, layer PTR destin_layer, bool PTR error_flag_to_use, bool fully_connect_layers = false) = 0;
 	virtual	bool setup (string name, layer PTR source_layer, layer PTR destin_layer, bool PTR error_flag_to_use, bool fully_connect_layers = false) = 0;
     virtual	bool setup (string name, layer PTR source_layer, layer PTR destin_layer, bool PTR error_flag_to_use, bool fully_connect_layers, DATA min_random_weight, DATA max_random_weight) = 0;
@@ -77,11 +80,17 @@ class Connection_Set : public connection_set
  bool connect (const int source_pe, const int destin_pe, const DATA initial_weight);
  bool fully_connect (bool group_by_source = false);
 
- // Note: the set_connection_weight functions are added for initializing weights. Using in processing is not recommented.
+ DATA get_connection_weight(int connection);					// returns 0 if not successful
+ bool set_connection_weight(int connection, DATA value);
+
+ // Note: the following set_connection_weight... functions are added for initializing weights. Using in processing is not recommented.
  void set_connection_weights (DATA value);
  void set_connection_weights_random(DATA min_random_value, DATA max_random_value);
  bool set_connection_weight (const int source_pe, const int destin_pe, const DATA new_weight);
 
+ // set values in misc internal register variable (found in connections)
+ bool set_misc(DATA * data, int dimension);
+
  string description ();
  void draw ();
  int  size();						                                      // number of connections in set
@@ -287,6 +296,33 @@ void Connection_Set<CONNECTION_TYPE>::set_connection_weights_random(DATA min_ran
      while (connections.goto_next());
 }
 
+
+//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+// returns 0 if unsuccesful
+
+template <class CONNECTION_TYPE>
+DATA Connection_Set<CONNECTION_TYPE>::get_connection_weight (int connection)
+{
+ if(connection<0)
+ 	{warning("Invalid connection"); return 0;}
+ if(connection>=connections.size())
+ 	{warning("Invalid connection"); return 0;}
+return connections[connection].weight();
+}
+
+//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+
+template <class CONNECTION_TYPE>
+bool Connection_Set<CONNECTION_TYPE>::set_connection_weight (int connection, DATA value)
+{
+if(connection<0)
+	{warning("Invalid connection"); return false;}
+if(connection>=connections.size())
+	{warning("Invalid connection"); return false;}
+connections[connection].weight()=value;
+return true;
+}
+
 //- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 // Not for general use. Added for initializing weights to particular values etc.
 
@@ -558,6 +594,26 @@ bool Connection_Set<CONNECTION_TYPE>::has_destin_layer()
 return (mp_destin_layer != NULL);
 }
 
+//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+// set misc variable in connections
+
+template <class CONNECTION_TYPE>
+bool Connection_Set<CONNECTION_TYPE>::set_misc(DATA * data, int dimension)
+{
+	if (NOT no_error()) return false;
+	if (data == NULL) return false;
+	if (dimension NEQL size())
+	{ warning ("Incompatible vector dimension (number of connections vs vector length)");
+		return false; }
+	if(NOT connections.goto_first()) return false;
+	for (int i = 0; i < dimension; i++)
+		{
+		connections.current().misc = data[i];                    // sets data to respective connection misc
+		if(NOT connections.goto_next()) i=dimension;
+		}
+	return true;
+}
+
 //- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 } // end of namespace nnlib2
